@@ -36,6 +36,12 @@ MainWindow::MainWindow(QWidget *parent):
     ui->pushButtonGet->setText(tr("Show Current"));
     ui->pushButtonSwapUsage->setText(tr("Check Status"));
 
+    // Set Button Icons
+    ui->pushButtonSwap->setIcon(QPixmap("/opt/flopswap/icons/refresh_icon&32.png"));
+    ui->pushButtonEject->setIcon(QPixmap("/opt/flopswap/icons/eject_icon&32.png"));
+    ui->pushButtonGet->setIcon(QPixmap("/opt/flopswap/icons/info_icon&32.png"));
+    ui->pushButtonSwapUsage->setIcon(QPixmap("/opt/flopswap/icons/checkbox_checked_icon&32.png"));
+
     //Set Action Text
     ui->actionSettings->setText(tr("Settings"));
     ui->actionReadme->setText(tr("Quick Guide"));
@@ -137,6 +143,7 @@ void MainWindow::connectSignals()
     connect(new QShortcut(QKeySequence(Qt::Key_S), this), SIGNAL(activated()), this, SLOT(on_pushButtonSwapUsage_clicked()));
 }
 
+
 //Initial Setup Text
 void MainWindow::initialshow()
 {
@@ -167,6 +174,7 @@ void MainWindow::initialseen()
         }
 }
 
+
 //Initial QSettings for Spin Box
 void MainWindow::initialpsb()
 {
@@ -180,7 +188,7 @@ void MainWindow::initialpsb()
 
 //Buttons
 void MainWindow::on_pushButtonSwap_clicked()
-{
+{ 
     m_process->start("sudo /opt/flopswap/script/swapswitch.sh");
 }
 
